==> pynorare-0.1.0.tar.gz: pynorare-0.1.0/setup.py <==
from setuptools import setup, find_packages


setup(
    name='pynorare',
    version='0.1.0',
    description='A Python library to handle NoRaRe data',
    author='Johann-Mattis List',
    author_email='mattis.list@lingpy.org',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    keywords='',
    license='Apache 2.0',
    url='https://github.com/concepticon/pynorare',
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'norare=pynorare.__main__:main',
        ],
    },
    platforms='any',
    python_requires='>=3.5',
    install_requires=[
        'pyconcepticon>=2.5',
        'attrs>=18.2',
        'clldutils>=3.1.2',
        'cldfcatalog>=1.3',
        'csvw>=1.6',
        "tqdm",
        'uritemplate',
        'xlrd'
    ],
    extras_require={
        'dev': ['flake8', 'wheel', 'twine'],
        'test': [
            'pytest>=5',
            'pytest-mock',
            'mock',
            'pytest-cov',
            'coverage>=4.2',
        ],
    },
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
)

==> pynorare-0.2.1.tar.gz: pynorare-0.2.1/setup.py <==
from setuptools import setup, find_packages


setup(
    name='pynorare',
    version='0.2.1',
    description='A Python library to handle NoRaRe data',
    author='Johann-Mattis List and Robert Forkel',
    author_email='mattis.list@lingpy.org',
    long_description=open('README.md').read(),
    long_description_content_type='text/markdown',
    keywords='',
    license='Apache 2.0',
    url='https://github.com/concepticon/pynorare',
    packages=find_packages(where='src'),
    package_dir={'': 'src'},
    include_package_data=True,
    zip_safe=False,
    entry_points={
        'console_scripts': [
            'norare=pynorare.__main__:main',
        ],
    },
    platforms='any',
    python_requires='>=3.5',
    install_requires=[
        'pyconcepticon>=2.5',
        'attrs>=18.2',
        'clldutils>=3.1.2',
        'cldfcatalog>=1.3',
        'csvw>=1.6',
        "tqdm",
        'uritemplate',
        'xlrd~=1.0'
    ],
    extras_require={
        'dev': ['flake8', 'wheel', 'twine', 'tox'],
        'test': [
            'pytest>=5',
            'pytest-mock',
            'pytest-cov',
            'coverage>=4.2',
        ],
    },
    classifiers=[
        'Development Status :: 2 - Pre-Alpha',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: Apache Software License',
        'Natural Language :: English',
        'Operating System :: OS Independent',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.6',
        'Programming Language :: Python :: 3.7',
        'Programming Language :: Python :: 3.8',
        'Programming Language :: Python :: 3.9',
        'Programming Language :: Python :: Implementation :: CPython',
        'Programming Language :: Python :: Implementation :: PyPy'
    ],
)
